Structs
- Column
Def - Defines how a Rust field maps to a visible XLSX column.
- RowView
- A typed view over one parsed spreadsheet row.
- Sheet
Data - Homogeneous sheet data for multi-sheet workbook generation.
- Sheet
Options - Single-sheet write options for Phase 1.
Enums
- Cell
Value - A small, explicit value model for the cell types supported in Phase 1.
- Excel
Error - Errors returned by schema validation, XLSX writing, and XLSX parsing.
Traits
- Excel
Row - Implement this trait to convert a struct to and from XLSX rows.
Functions
- from_
reader - Parse the first worksheet in an XLSX reader into typed rows.
- from_
xlsx - Parse the first worksheet in an XLSX byte slice into typed rows.
- to_xlsx
- Convert a slice of row values into a single-sheet XLSX workbook.
- to_
xlsx_ multi - Convert multiple homogeneous sheets into one XLSX workbook.
- validate_
columns - Validate schema metadata and return columns sorted by ascending order.